@@ -1,18 +1,18 @@
 """Beautiful Captions - Fast and elegant video captioning library."""
 
 from .core.config import CaptionConfig, StyleConfig, AnimationConfig, DiarizationConfig
-from .core.caption import add_captions, process_video, extract_subtitles, caption_stream
+from .core.caption import subtitles_from_srt, add_subtitles, extract_subtitles, caption_stream
 from .core.video import Video
 from .styling.style import StyleManager, FontManager
 from .styling.animation import AnimationFactory, create_animation_for_subtitle
 from .utils.subtitles import style_srt_content
 
-__version__ = "0.1.18"
+__version__ = "0.1.60"
 
 __all__ = [
     # Main functions
-    "add_captions",
-    "process_video",
+    "subtitles_from_srt",
+    "add_subtitles",
     "extract_subtitles",
     "caption_stream",
     
